@@ -17,8 +17,8 @@ def main() -> None:
     df = pd.read_csv(URL, sep="\t")
     del df[df.columns[0]]
     df = df[df.description.notna()]
-    df = df[df["prefix"].map(lambda p: bioregistry.get_description(p) is None)]
-    df = df[df["prefix"].map(lambda p: bioregistry.get_obofoundry_prefix(p) is None)]
+    df = df[df["prefix"].map(_has_description)]
+    df = df[df["prefix"].map(_is_obofoundry)]
     click.echo(df.to_markdown())
     r = dict(bioregistry.read_registry())
     for prefix, description in df[["prefix", "description"]].values:
@@ -26,5 +26,13 @@ def main() -> None:
     bioregistry.write_registry(r)
 
 
+def _has_description(prefix: str) -> bool:
+    return bioregistry.get_description(prefix) is None
+
+
+def _is_obofoundry(prefix: str) -> bool:
+    return bioregistry.get_obofoundry_prefix(prefix) is None
+
+
 if __name__ == "__main__":
     main()
